"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.updateJson = exports.writeJson = exports.readJson = void 0;
const json_1 = require("@nrwl/tao/src/utils/json");
/**
 * Reads a document for host, removes all comments and parses JSON.
 *
 * @param host - file system tree
 * @param path - file path
 * @param options - Optional JSON Parse Options
 */
function readJson(host, path, options) {
    if (!host.exists(path)) {
        throw new Error(`Cannot find ${path}`);
    }
    try {
        return json_1.parseJson(host.read(path, 'utf-8'), options);
    }
    catch (e) {
        throw new Error(`Cannot parse ${path}: ${e.message}`);
    }
}
exports.readJson = readJson;
/**
 * Writes a JSON value to the file system tree

 * @param host File system tree
 * @param path Path of JSON file in the Tree
 * @param value Serializable value to write
 * @param options Optional JSON Serialize Options
 */
function writeJson(host, path, value, options) {
    host.write(path, json_1.serializeJson(value, options));
}
exports.writeJson = writeJson;
/**
 * Updates a JSON value to the file system tree
 *
 * @param host File system tree
 * @param path Path of JSON file in the Tree
 * @param updater Function that maps the current value of a JSON document to a new value to be written to the document
 * @param options Optional JSON Parse and Serialize Options
 */
function updateJson(host, path, updater, options) {
    const updatedValue = updater(readJson(host, path, options));
    writeJson(host, path, updatedValue, options);
}
exports.updateJson = updateJson;
//# sourceMappingURL=json.js.map